@@ -341,7 +341,7 @@ meta_theme_gtk_calc_geometry (MetaThemeImpl     *impl,
   int title_right_edge;
   int width, height;
   int scale;
-  int content_width, content_height;
+  int content_height;
   int button_width, button_height;
   int min_size_for_rounding;
 
@@ -363,9 +363,6 @@ meta_theme_gtk_calc_geometry (MetaThemeImpl     *impl,
   /* Scale geometry for HiDPI, see comment in meta_theme_gtk_draw_frame () */
   scale = meta_theme_impl_get_scale (impl);
 
-  content_width = width -
-                  borders.invisible.left - layout->gtk.frame_border.left * scale -
-                  borders.invisible.right - layout->gtk.frame_border.right * scale;
   content_height = borders.visible.top - layout->gtk.frame_border.top * scale;
 
   button_width = MAX ((gint) layout->gtk.icon_size, layout->gtk.button_min_size.width) +
@@ -407,9 +404,9 @@ meta_theme_gtk_calc_geometry (MetaThemeImpl     *impl,
           if (button->visible)
             {
               if (button->type != META_BUTTON_TYPE_SPACER)
-                n_left++;
+                n_right++;
               else
-                n_left_spacers++;
+                n_right_spacers++;
             }
         }
     }
@@ -426,6 +423,13 @@ meta_theme_gtk_calc_geometry (MetaThemeImpl     *impl,
   while (n_left > 0 || n_right > 0)
     {
       int space_used_by_buttons;
+      int space_available;
+
+      space_available = fgeom->width -
+                        borders.total.left -
+                        layout->gtk.titlebar_border.left * scale -
+                        layout->gtk.titlebar_border.right * scale -
+                        borders.total.right;
 
       space_used_by_buttons = 0;
 
@@ -441,7 +445,7 @@ meta_theme_gtk_calc_geometry (MetaThemeImpl     *impl,
       space_used_by_buttons += (button_width * 0.75) * n_right_spacers;
       space_used_by_buttons += layout->gtk.titlebar_spacing * scale * MAX (n_right - 1, 0);
 
-      if (space_used_by_buttons <= content_width)
+      if (space_used_by_buttons <= space_available)
         break; /* Everything fits, bail out */
 
       /* First try to remove separators */
@@ -549,9 +553,7 @@ meta_theme_gtk_calc_geometry (MetaThemeImpl     *impl,
         }
 
       x = rect.x - layout->gtk.button_margin.left * scale;
-
-      if (i > 0)
-        x -= layout->gtk.titlebar_spacing * scale;
+      x -= layout->gtk.titlebar_spacing * scale;
     }
 
   /* save right edge of titlebar for later use */
@@ -604,9 +606,7 @@ meta_theme_gtk_calc_geometry (MetaThemeImpl     *impl,
         }
 
       x = rect.x + rect.width + layout->gtk.button_margin.right * scale;
-
-      if (i < button_layout->n_left_buttons - 1)
-        x += layout->gtk.titlebar_spacing * scale;
+      x += layout->gtk.titlebar_spacing * scale;
     }
 
   /* Center vertically in the available content area */
@@ -747,8 +747,19 @@ meta_theme_gtk_draw_frame (MetaThemeImpl           *impl,
       else if (x + text_width > (fgeom->title_rect.x + fgeom->title_rect.width) / scale)
         x = (fgeom->title_rect.x + fgeom->title_rect.width) / scale - text_width;
 
+      cairo_save (cr);
+
+      cairo_rectangle (cr,
+                       fgeom->title_rect.x / scale,
+                       fgeom->title_rect.y / scale,
+                       fgeom->title_rect.width / scale,
+                       fgeom->title_rect.height / scale);
+      cairo_clip (cr);
+
       context = meta_style_info_get_style (style_info, META_STYLE_ELEMENT_TITLE);
       gtk_render_layout (context, cr, x, y, title_layout);
+
+      cairo_restore (cr);
     }
 
   context = meta_style_info_get_style (style_info, META_STYLE_ELEMENT_BUTTON);
