@@ -970,6 +970,13 @@ window_has_shadow (MetaCompositorXRender *xrender,
   if (xrender->have_shadows == FALSE)
     return FALSE;
 
+  /* Do not add shadows to client side decorated windows */
+  if (meta_window_is_client_decorated (cw->window))
+    {
+      meta_verbose ("Window might have shadow because it is client side decorated\n");
+      return FALSE;
+    }
+
   /* Do not add shadows to fullscreen windows */
   if (meta_window_is_fullscreen (cw->window))
     {
@@ -984,15 +991,16 @@ window_has_shadow (MetaCompositorXRender *xrender,
       return FALSE;
     }
 
-  /* Do not add shadows if GTK+ theme is used */
-  if (meta_prefs_get_theme_type () == META_THEME_TYPE_GTK)
-    {
-      meta_verbose ("Window has shadow from GTK+ theme\n");
-      return FALSE;
-    }
-
+  /* Add shadows to windows with frame */
   if (meta_window_get_frame (cw->window))
     {
+      /* Do not add shadows if GTK+ theme is used */
+      if (meta_prefs_get_theme_type () == META_THEME_TYPE_GTK)
+        {
+          meta_verbose ("Window might have shadow from GTK+ theme\n");
+          return FALSE;
+        }
+
       meta_verbose ("Window has shadow because it has a frame\n");
       return TRUE;
     }
@@ -1747,7 +1755,7 @@ repair_win (MetaCompositorXRender *xrender,
   Display *xdisplay = meta_display_get_xdisplay (display);
   XserverRegion parts;
 
-  meta_error_trap_push (NULL);
+  meta_error_trap_push (display);
 
   if (!cw->damaged)
     {
@@ -1761,7 +1769,7 @@ repair_win (MetaCompositorXRender *xrender,
       XFixesTranslateRegion (xdisplay, parts, cw->rect.x, cw->rect.y);
     }
 
-  meta_error_trap_pop (NULL);
+  meta_error_trap_pop (display);
 
   dump_xserver_region (xrender, "repair_win", parts);
   add_damage (xrender, parts);
@@ -2169,25 +2177,22 @@ process_property_notify (MetaCompositorXRender *xrender,
   if (event->atom == display->atom__XROOTPMAP_ID ||
       event->atom == display->atom__XSETROOT_ID)
     {
-      screen = meta_display_screen_for_root (display, event->window);
-      if (screen)
+      screen = meta_display_get_screen (display);
+
+      if (event->window == meta_screen_get_xroot (screen) &&
+          xrender->root_tile != None)
         {
-          Window xroot = meta_screen_get_xroot (screen);
+          XClearArea (xdisplay, event->window, 0, 0, 0, 0, TRUE);
+          XRenderFreePicture (xdisplay, xrender->root_tile);
+          xrender->root_tile = None;
 
-          if (xrender->root_tile)
-            {
-              XClearArea (xdisplay, xroot, 0, 0, 0, 0, TRUE);
-              XRenderFreePicture (xdisplay, xrender->root_tile);
-              xrender->root_tile = None;
+          /* Damage the whole screen as we may need to redraw the
+           * background ourselves
+           */
+          damage_screen (xrender);
 
-              /* Damage the whole screen as we may need to redraw the
-                 background ourselves */
-              damage_screen (xrender);
-
-              add_repair (xrender);
-
-              return;
-            }
+          add_repair (xrender);
+          return;
         }
     }
 
@@ -2694,7 +2699,7 @@ meta_compositor_xrender_process_event (MetaCompositor *compositor,
    * X errors. This is really a hack, but I'm afraid I don't understand
    * enough about Metacity/X to know how else you are supposed to do it
    */
-  meta_error_trap_push (NULL);
+  meta_error_trap_push (display);
 
   switch (event->type)
     {
@@ -2712,7 +2717,7 @@ meta_compositor_xrender_process_event (MetaCompositor *compositor,
       break;
     }
 
-  meta_error_trap_pop (NULL);
+  meta_error_trap_pop (display);
 }
 
 static cairo_surface_t *
