@@ -83,7 +83,6 @@ item(_XSETROOT_ID)
 item(_NET_WM_SYNC_REQUEST)
 item(_NET_WM_SYNC_REQUEST_COUNTER)
 item(_NET_WM_VISIBLE_NAME)
-item(_NET_WM_VISIBLE_ICON_NAME)
 item(_NET_SUPPORTING_WM_CHECK)
 
 /* But I suppose it's quite reasonable not to advertise using
@@ -113,7 +112,10 @@ item(_NET_WM_WINDOW_TYPE_UTILITY)
 item(_NET_WM_WINDOW_TYPE_SPLASH)
 item(_NET_WM_WINDOW_TYPE_DIALOG)
 item(_NET_WM_WINDOW_TYPE_DROPDOWN_MENU)
+item(_NET_WM_WINDOW_TYPE_POPUP_MENU)
 item(_NET_WM_WINDOW_TYPE_TOOLTIP)
+item(_NET_WM_WINDOW_TYPE_NOTIFICATION)
+item(_NET_WM_WINDOW_TYPE_COMBO)
 item(_NET_WM_WINDOW_TYPE_DND)
 item(_NET_WM_WINDOW_TYPE_NORMAL)
 item(_NET_WM_STATE_MODAL)
@@ -121,7 +123,6 @@ item(_NET_CLIENT_LIST)
 item(_NET_CLIENT_LIST_STACKING)
 item(_NET_WM_STATE_SKIP_TASKBAR)
 item(_NET_WM_STATE_SKIP_PAGER)
-item(_NET_WM_ICON_NAME)
 item(_NET_WM_ICON)
 item(_NET_WM_ICON_GEOMETRY)
 item(_NET_WM_MOVERESIZE)
@@ -163,6 +164,7 @@ item(_NET_WM_ACTION_BELOW)
 item(_NET_WM_STATE_STICKY)
 item(_NET_WM_FULLSCREEN_MONITORS)
 item(_NET_WM_STATE_FOCUSED)
+item(_NET_WM_OPAQUE_REGION)
 item(_NET_RESTACK_WINDOW)
 item(_NET_WM_WINDOW_OPACITY)
 
