@@ -387,8 +387,9 @@ merge_spanning_rects_in_region (GList *region)
 
   if (region == NULL)
     {
-      meta_warning ("Region to merge was empty!  Either you have a some "
-                    "pathological STRUT list or there's a bug somewhere!\n");
+      g_warning ("Region to merge was empty!  Either you have a some "
+                 "pathological STRUT list or there's a bug somewhere!");
+
       return NULL;
     }
 
@@ -879,7 +880,7 @@ meta_rectangle_clamp_to_fit_into_region (const GList         *spanning_rects,
   /* Clamp rect appropriately */
   if (best_rect == NULL)
     {
-      meta_warning ("No rect whose size to clamp to found!\n");
+      g_warning ("No rect whose size to clamp to found!");
 
       /* If it doesn't fit, at least make it no bigger than it has to be */
       if (!(fixed_directions & FIXED_DIRECTION_X))
@@ -946,7 +947,9 @@ meta_rectangle_clip_to_region (const GList         *spanning_rects,
 
   /* Clip rect appropriately */
   if (best_rect == NULL)
-    meta_warning ("No rect to clip to found!\n");
+    {
+      g_warning ("No rect to clip to found!");
+    }
   else
     {
       /* Extra precaution with checking fixed direction shouldn't be needed
@@ -1042,7 +1045,9 @@ meta_rectangle_shove_into_region (const GList         *spanning_rects,
 
   /* Shove rect appropriately */
   if (best_rect == NULL)
-    meta_warning ("No rect to shove into found!\n");
+    {
+      g_warning ("No rect to shove into found!");
+    }
   else
     {
       /* Extra precaution with checking fixed direction shouldn't be needed
@@ -1526,6 +1531,8 @@ add_edges (GList               *cur_edges,
           temp_edge->rect.y      += temp_edge->rect.height;
           temp_edge->rect.height  = 0;
           break;
+        default:
+          break;
         }
       temp_edge->edge_type = META_EDGE_SCREEN;
       cur_edges = g_list_prepend (cur_edges, temp_edge);
