@@ -467,23 +467,6 @@ setup_constraint_info (ConstraintInfo      *info,
     meta_workspace_get_onxinerama_region (cur_workspace,
                                           xinerama_info->number);
 
-  /* Workaround braindead legacy apps that don't know how to
-   * fullscreen themselves properly - don't get fooled by
-   * windows which are client decorated; that's not the same
-   * as fullscreen, even if there are no struts making the
-   * workarea smaller than the monitor.
-   */
-  if (meta_prefs_get_force_fullscreen() &&
-      (window->decorated || !meta_window_is_client_decorated (window)) &&
-      meta_rectangle_equal (new, &xinerama_info->rect) &&
-      window->has_fullscreen_func &&
-      !window->fullscreen)
-    {
-      g_warning ("Treating resize request of legacy application %s as a "
-                 "fullscreen request", window->desc);
-      meta_window_make_fullscreen_internal (window);
-    }
-
   /* Log all this information for debugging */
   meta_topic (META_DEBUG_GEOMETRY,
               "Setting up constraint info:\n"
