@@ -63,13 +63,9 @@
 #include <X11/extensions/shape.h>
 
 #define META_MINIMIZE_ANIMATION_LENGTH 0.25
-#define META_SHADE_ANIMATION_LENGTH 0.2
 
 #include <string.h>
 
-typedef struct MetaEffect MetaEffect;
-typedef struct MetaEffectPriv MetaEffectPriv;
-
 typedef struct
 {
   MetaScreen *screen;
@@ -85,164 +81,26 @@ typedef struct
 
 } BoxAnimationContext;
 
-/**
- * Information we need to know during a maximise or minimise effect.
- */
-typedef struct
-{
-  /** This is the normal-size window. */
-  MetaRectangle window_rect;
-  /** This is the size of the window when it's an icon. */
-  MetaRectangle icon_rect;
-} MetaMinimizeEffect, MetaUnminimizeEffect;
-
-struct MetaEffectPriv
-{
-  MetaEffectFinished finished;
-  gpointer           finished_data;
-};
-
-struct MetaEffect
-{
-  /** The window the effect is applied to. */
-  MetaWindow *window;
-  /** Which effect is happening here. */
-  MetaEffectType type;
-  /** The effect handler can hang data here. */
-  gpointer info;
-
-  union
-  {
-    MetaMinimizeEffect      minimize;
-    /* ... and theoretically anything else */
-  } u;
-
-  MetaEffectPriv *priv;
-};
-
-static void run_default_effect_handler (MetaEffect *effect);
-static void run_handler (MetaEffect *effect);
-static void effect_free (MetaEffect *effect);
-
-static MetaEffect *
-create_effect (MetaEffectType      type,
-               MetaWindow         *window,
-               MetaEffectFinished  finished,
-               gpointer            finished_data);
-
-static void
-draw_box_animation (MetaScreen     *screen,
-                    MetaRectangle  *initial_rect,
-                    MetaRectangle  *destination_rect,
-                    double          seconds_duration);
-
-/**
- * Creates an effect.
- *
- */
-static MetaEffect*
-create_effect (MetaEffectType      type,
-               MetaWindow         *window,
-               MetaEffectFinished  finished,
-               gpointer            finished_data)
-{
-    MetaEffect *effect = g_new (MetaEffect, 1);
-
-    effect->type = type;
-    effect->window = window;
-    effect->priv = g_new (MetaEffectPriv, 1);
-    effect->priv->finished = finished;
-    effect->priv->finished_data = finished_data;
-
-    return effect;
-}
-
-/**
- * Destroys an effect.  If the effect has a "finished" hook, it will be
- * called before cleanup.
- *
- * \param effect  The effect.
- */
-static void
-effect_free (MetaEffect *effect)
-{
-  if (effect->priv->finished)
-    effect->priv->finished (effect->priv->finished_data);
-
-  g_free (effect->priv);
-  g_free (effect);
-}
+static void draw_box_animation (MetaScreen    *screen,
+                                MetaRectangle *initial_rect,
+                                MetaRectangle *destination_rect,
+                                double         seconds_duration);
 
 void
-meta_effect_run_focus (MetaWindow	    *window,
-		       MetaEffectFinished   finished,
-		       gpointer		    data)
+meta_effect_run_minimize (MetaWindow    *window,
+                          MetaRectangle *window_rect,
+                          MetaRectangle *icon_rect)
 {
-    MetaEffect *effect;
+  g_return_if_fail (window != NULL);
+  g_return_if_fail (icon_rect != NULL);
 
-    g_return_if_fail (window != NULL);
-
-    effect = create_effect (META_EFFECT_FOCUS, window, finished, data);
-
-    run_handler (effect);
+  if (meta_prefs_get_gnome_animations ())
+    {
+      draw_box_animation (window->screen, window_rect, icon_rect,
+                          META_MINIMIZE_ANIMATION_LENGTH);
+    }
 }
 
-void
-meta_effect_run_minimize (MetaWindow         *window,
-                          MetaRectangle      *window_rect,
-                          MetaRectangle      *icon_rect,
-                          MetaEffectFinished  finished,
-                          gpointer            data)
-{
-    MetaEffect *effect;
-
-    g_return_if_fail (window != NULL);
-    g_return_if_fail (icon_rect != NULL);
-
-    effect = create_effect (META_EFFECT_MINIMIZE, window, finished, data);
-
-    effect->u.minimize.window_rect = *window_rect;
-    effect->u.minimize.icon_rect = *icon_rect;
-
-    run_handler (effect);
-}
-
-void
-meta_effect_run_unminimize (MetaWindow         *window,
-                            MetaRectangle      *window_rect,
-                            MetaRectangle      *icon_rect,
-                            MetaEffectFinished  finished,
-                            gpointer            data)
-{
-    MetaEffect *effect;
-
-    g_return_if_fail (window != NULL);
-    g_return_if_fail (icon_rect != NULL);
-
-    effect = create_effect (META_EFFECT_UNMINIMIZE, window, finished, data);
-
-    effect->u.minimize.window_rect = *window_rect;
-    effect->u.minimize.icon_rect = *icon_rect;
-
-    run_handler (effect);
-}
-
-void
-meta_effect_run_close (MetaWindow         *window,
-		       MetaEffectFinished  finished,
-		       gpointer            data)
-{
-    MetaEffect *effect;
-
-    g_return_if_fail (window != NULL);
-
-    effect = create_effect (META_EFFECT_CLOSE, window,
-                            finished, data);
-
-    run_handler (effect);
-}
-
-
 /* old ugly minimization effect */
 
 static void
@@ -315,7 +173,7 @@ effects_draw_box_animation_timeout (BoxAnimationContext *context)
   if (elapsed < 0)
     {
       /* Probably the system clock was set backwards? */
-      meta_warning ("System clock seemed to go backwards?\n");
+      g_warning ("System clock seemed to go backwards?");
       elapsed = G_MAXDOUBLE; /* definitely done. */
     }
 
@@ -356,7 +214,7 @@ effects_draw_box_animation_timeout (BoxAnimationContext *context)
   return TRUE;
 }
 
-void
+static void
 draw_box_animation (MetaScreen     *screen,
                     MetaRectangle  *initial_rect,
                     MetaRectangle  *destination_rect,
@@ -614,35 +472,3 @@ meta_effects_end_wireframe (MetaScreen          *screen,
   meta_display_ungrab (screen->display);
   meta_ui_pop_delay_exposes (screen->ui);
 }
-
-static void
-run_default_effect_handler (MetaEffect *effect)
-{
-    switch (effect->type)
-    {
-    case META_EFFECT_MINIMIZE:
-       draw_box_animation (effect->window->screen,
-                     &(effect->u.minimize.window_rect),
-                     &(effect->u.minimize.icon_rect),
-                     META_MINIMIZE_ANIMATION_LENGTH);
-       break;
-
-    case META_EFFECT_UNMINIMIZE:
-    case META_EFFECT_FOCUS:
-    case META_EFFECT_CLOSE:
-    case META_NUM_EFFECTS:
-      break;
-
-    default:
-       break;
-    }
-}
-
-static void
-run_handler (MetaEffect *effect)
-{
-  if (meta_prefs_get_gnome_animations ())
-    run_default_effect_handler (effect);
-
-  effect_free (effect);
-}
