@@ -30,7 +30,6 @@
 #include "bell.h"
 #include "errors.h"
 #include "keybindings.h"
-#include "prefs.h"
 
 #define EVENT_MASK (SubstructureRedirectMask |                     \
                     StructureNotifyMask | SubstructureNotifyMask | \
@@ -51,6 +50,9 @@ update_input_shape (MetaFrame *frame)
   Display *xdisplay;
   XserverRegion region;
 
+  if (!frame->window->display->have_xfixes)
+    return;
+
   meta_frame_calc_borders (frame, &borders);
 
   rect.x = borders.invisible.left - borders.resize.left;
@@ -65,31 +67,16 @@ update_input_shape (MetaFrame *frame)
   XFixesDestroyRegion (xdisplay, region);
 }
 
-static void
-prefs_changed_callback (MetaPreference preference,
-                        gpointer       data)
-{
-  MetaFrame *frame = (MetaFrame *) data;
-
-  if (preference == META_PREF_COMPOSITING_MANAGER)
-    {
-      frame->need_reapply_frame_shape = TRUE;
-      update_shape (frame);
-    }
-}
-
 void
 meta_window_ensure_frame (MetaWindow *window)
 {
   MetaFrame *frame;
   XSetWindowAttributes attrs;
+  gulong create_serial;
 
   if (window->frame)
     return;
 
-  /* See comment below for why this is required. */
-  meta_display_grab (window->display);
-
   frame = g_new (MetaFrame, 1);
 
   frame->window = window;
@@ -117,7 +104,12 @@ meta_window_ensure_frame (MetaWindow *window)
                                                 frame->rect.x,
                                                 frame->rect.y,
                                                 frame->rect.width,
-                                                frame->rect.height);
+                                                frame->rect.height,
+                                                &create_serial);
+
+  meta_stack_tracker_record_add (window->screen->stack_tracker,
+                                 frame->xwindow,
+                                 create_serial);
 
   meta_verbose ("Frame for %s is 0x%lx\n", frame->window->desc, frame->xwindow);
   attrs.event_mask = EVENT_MASK;
@@ -126,14 +118,6 @@ meta_window_ensure_frame (MetaWindow *window)
 
   meta_display_register_x_window (window->display, &frame->xwindow, window);
 
-  /* Reparent the client window; it may be destroyed,
-   * thus the error trap. We'll get a destroy notify later
-   * and free everything. Comment in FVWM source code says
-   * we need a server grab or the child can get its MapNotify
-   * before we've finished reparenting and getting the decoration
-   * window onscreen, so ensure_frame must be called with
-   * a grab.
-   */
   meta_error_trap_push (window->display);
   if (window->mapped)
     {
@@ -148,6 +132,10 @@ meta_window_ensure_frame (MetaWindow *window)
   window->rect.x = 0;
   window->rect.y = 0;
 
+  meta_stack_tracker_record_remove (window->screen->stack_tracker,
+                                    window->xwindow,
+                                    XNextRequest (window->display->xdisplay));
+
   XReparentWindow (window->display->xdisplay,
                    window->xwindow,
                    frame->xwindow,
@@ -175,10 +163,6 @@ meta_window_ensure_frame (MetaWindow *window)
   /* Shape mask */
   update_input_shape (frame);
   update_shape (frame);
-
-  meta_display_ungrab (window->display);
-
-  meta_prefs_add_listener (prefs_changed_callback, frame);
 }
 
 void
@@ -194,8 +178,6 @@ meta_window_destroy_frame (MetaWindow *window)
 
   frame = window->frame;
 
-  meta_prefs_remove_listener (prefs_changed_callback, frame);
-
   meta_frame_calc_borders (frame, &borders);
 
   meta_bell_notify_frame_destroy (frame);
@@ -214,6 +196,11 @@ meta_window_destroy_frame (MetaWindow *window)
                   "Incrementing unmaps_pending on %s for reparent back to root\n", window->desc);
       window->unmaps_pending += 1;
     }
+
+  meta_stack_tracker_record_add (window->screen->stack_tracker,
+                                 window->xwindow,
+                                 XNextRequest (window->display->xdisplay));
+
   XReparentWindow (window->display->xdisplay,
                    window->xwindow,
                    window->screen->xroot,
