@@ -177,19 +177,19 @@ find_next_cascade (MetaWindow *window,
           cascade_y = wy + titlebar_rect.height;
 
           /* If we go off the screen, start over with a new cascade */
-	  if (((cascade_x + window_width) >
+          if (((cascade_x + window_width) >
                (work_area.x + work_area.width)) ||
               ((cascade_y + window_height) >
-	       (work_area.y + work_area.height)))
-	    {
-	      cascade_x = MAX (0, work_area.x);
-	      cascade_y = MAX (0, work_area.y);
+               (work_area.y + work_area.height)))
+            {
+              cascade_x = MAX (0, work_area.x);
+              cascade_y = MAX (0, work_area.y);
 
 #define CASCADE_INTERVAL 50 /* space between top-left corners of cascades */
               cascade_stage += 1;
-	      cascade_x += CASCADE_INTERVAL * cascade_stage;
+              cascade_x += CASCADE_INTERVAL * cascade_stage;
 
-	      /* start over with a new cascade translated to the right, unless
+              /* start over with a new cascade translated to the right, unless
                * we are out of space
                */
               if ((cascade_x + window_width) <
@@ -204,7 +204,7 @@ find_next_cascade (MetaWindow *window,
                   cascade_x = MAX (0, work_area.x);
                   break;
                 }
-	    }
+            }
         }
       else
         {
@@ -394,6 +394,13 @@ rectangle_overlaps_some_window (MetaRectangle *rect,
         case META_WINDOW_DESKTOP:
         case META_WINDOW_DIALOG:
         case META_WINDOW_MODAL_DIALOG:
+        case META_WINDOW_DROPDOWN_MENU:
+        case META_WINDOW_POPUP_MENU:
+        case META_WINDOW_TOOLTIP:
+        case META_WINDOW_NOTIFICATION:
+        case META_WINDOW_COMBO:
+        case META_WINDOW_DND:
+        case META_WINDOW_OVERRIDE_OTHER:
           break;
 
         case META_WINDOW_NORMAL:
@@ -503,7 +510,7 @@ find_first_fit (MetaWindow *window,
                 MetaFrameBorders *borders,
                 /* visible windows on relevant workspaces */
                 GList      *windows,
-		int         xinerama,
+                int         xinerama,
                 int         x,
                 int         y,
                 int        *new_x,
@@ -544,16 +551,14 @@ find_first_fit (MetaWindow *window,
       rect.height += borders->visible.top + borders->visible.bottom;
     }
 
-#ifdef WITH_VERBOSE_MODE
     {
       char xinerama_location_string[RECT_LENGTH];
       meta_rectangle_to_string (&window->screen->xinerama_infos[xinerama].rect,
                                 xinerama_location_string);
       meta_topic (META_DEBUG_XINERAMA,
-		  "Natural xinerama is %s\n",
-		  xinerama_location_string);
+                  "Natural xinerama is %s\n",
+                  xinerama_location_string);
     }
-#endif
 
     meta_window_get_work_area_for_xinerama (window, xinerama, &work_area);
 
@@ -723,7 +728,7 @@ find_preferred_position (MetaWindow *window,
             break;
 
           default:
-            meta_warning ("Unknown window-placement option chosen.\n");
+            g_warning ("Unknown window-placement option chosen.");
             return FALSE;
             break;
         }
@@ -779,6 +784,13 @@ meta_window_place (MetaWindow        *window,
     case META_WINDOW_TOOLBAR:
     case META_WINDOW_MENU:
     case META_WINDOW_UTILITY:
+    case META_WINDOW_DROPDOWN_MENU:
+    case META_WINDOW_POPUP_MENU:
+    case META_WINDOW_TOOLTIP:
+    case META_WINDOW_NOTIFICATION:
+    case META_WINDOW_COMBO:
+    case META_WINDOW_DND:
+    case META_WINDOW_OVERRIDE_OTHER:
       goto done_no_constraints;
 
     default:
@@ -815,6 +827,13 @@ meta_window_place (MetaWindow        *window,
         case META_WINDOW_TOOLBAR:
         case META_WINDOW_MENU:
         case META_WINDOW_UTILITY:
+        case META_WINDOW_DROPDOWN_MENU:
+        case META_WINDOW_POPUP_MENU:
+        case META_WINDOW_TOOLTIP:
+        case META_WINDOW_NOTIFICATION:
+        case META_WINDOW_COMBO:
+        case META_WINDOW_DND:
+        case META_WINDOW_OVERRIDE_OTHER:
           if (window->size_hints.flags & PPosition)
             {
               meta_topic (META_DEBUG_PLACEMENT,
@@ -920,7 +939,7 @@ meta_window_place (MetaWindow        *window,
     GSList *all_windows;
     GSList *tmp;
 
-    all_windows = meta_display_list_windows (window->display);
+    all_windows = meta_display_list_windows (window->display, META_LIST_DEFAULT);
 
     tmp = all_windows;
     while (tmp != NULL)
@@ -1018,7 +1037,7 @@ meta_window_place (MetaWindow        *window,
                                       xi->number,
                                       x, y, &x, &y);
           g_list_free (focus_window_list);
-	}
+        }
 
       /* If that still didn't work, just place it where we can see as much
        * as possible.
