@@ -34,6 +34,7 @@
 #include "display-private.h"
 #include "screen.h"
 #include <X11/Xutil.h>
+#include "stack-tracker.h"
 #include "ui.h"
 
 typedef struct _MetaXineramaScreenInfo MetaXineramaScreenInfo;
@@ -91,6 +92,7 @@ struct _MetaScreen
   GList *workspaces;
 
   MetaStack *stack;
+  MetaStackTracker *stack_tracker;
 
   MetaCursor current_cursor;
 
@@ -112,9 +114,6 @@ struct _MetaScreen
   guint startup_sequence_timeout;
 #endif
 
-  Window wm_cm_selection_window;
-  guint32 wm_cm_timestamp;
-
   guint work_area_idle;
 
   int rows_of_workspaces;
@@ -129,9 +128,6 @@ struct _MetaScreen
 
   /* gc for XOR on root window */
   GC root_xor_gc;
-
-  /* Managed by compositor.c */
-  gpointer compositor_data;
 };
 
 MetaScreen*   meta_screen_new                 (MetaDisplay                *display,
