@@ -147,8 +147,6 @@ set_wm_icon_size_hint (MetaScreen *screen)
 static void
 reload_xinerama_infos (MetaScreen *screen)
 {
-  MetaDisplay *display;
-
   {
     GList *tmp;
 
@@ -163,8 +161,6 @@ reload_xinerama_infos (MetaScreen *screen)
       }
   }
 
-  display = screen->display;
-
   if (screen->xinerama_infos)
     g_free (screen->xinerama_infos);
 
@@ -175,18 +171,18 @@ reload_xinerama_infos (MetaScreen *screen)
   screen->display->xinerama_cache_invalidated = TRUE;
 
 #ifdef HAVE_XFREE_XINERAMA
-  if (XineramaIsActive (display->xdisplay))
+  if (XineramaIsActive (screen->display->xdisplay))
     {
       XineramaScreenInfo *infos;
       int n_infos;
       int i;
 
       n_infos = 0;
-      infos = XineramaQueryScreens (display->xdisplay, &n_infos);
+      infos = XineramaQueryScreens (screen->display->xdisplay, &n_infos);
 
       meta_topic (META_DEBUG_XINERAMA,
                   "Found %d Xinerama screens on display %s\n",
-                  n_infos, display->name);
+                  n_infos, screen->display->name);
 
       if (n_infos > 0)
         {
@@ -220,7 +216,7 @@ reload_xinerama_infos (MetaScreen *screen)
     {
       meta_topic (META_DEBUG_XINERAMA,
                   "No XFree86 Xinerama extension or XFree86 Xinerama inactive on display %s\n",
-                  display->name);
+                  screen->display->name);
     }
 #else
   meta_topic (META_DEBUG_XINERAMA,
@@ -279,7 +275,7 @@ reload_xinerama_infos (MetaScreen *screen)
     {
       meta_topic (META_DEBUG_XINERAMA,
                   "No Solaris Xinerama extension or Solaris Xinerama inactive on display %s\n",
-                  display->name);
+                  screen->display->name);
     }
 #else
   meta_topic (META_DEBUG_XINERAMA,
@@ -1135,12 +1131,12 @@ get_window_pixbuf (MetaWindow *window,
   if (surface == NULL)
     return NULL;
 
-  meta_error_trap_push (NULL);
+  meta_error_trap_push (display);
 
   pixbuf = meta_ui_get_pixbuf_from_surface (surface);
   cairo_surface_destroy (surface);
 
-  if (meta_error_trap_pop_with_return (NULL) != Success)
+  if (meta_error_trap_pop_with_return (display) != Success)
     g_clear_object (&pixbuf);
 
   if (pixbuf == NULL) 
@@ -1440,6 +1436,7 @@ meta_screen_tile_preview_hide (MetaScreen *screen)
 {
   if (screen->tile_preview_timeout_id > 0)
     g_source_remove (screen->tile_preview_timeout_id);
+  screen->tile_preview_timeout_id = 0;
 
   if (screen->tile_preview)
     meta_tile_preview_hide (screen->tile_preview);
