@@ -32,7 +32,7 @@
 #ifndef META_WINDOW_PRIVATE_H
 #define META_WINDOW_PRIVATE_H
 
-#include <config.h>
+#include "meta-compositor.h"
 #include "window.h"
 #include "screen-private.h"
 #include "util.h"
@@ -42,6 +42,8 @@
 #include <cairo.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
+G_BEGIN_DECLS
+
 typedef struct _MetaGroup MetaGroup;
 typedef struct _MetaWindowQueue MetaWindowQueue;
 
@@ -58,7 +60,14 @@ typedef enum
   META_WINDOW_TOOLBAR,
   META_WINDOW_MENU,
   META_WINDOW_UTILITY,
-  META_WINDOW_SPLASHSCREEN
+  META_WINDOW_SPLASHSCREEN,
+  META_WINDOW_DROPDOWN_MENU,
+  META_WINDOW_POPUP_MENU,
+  META_WINDOW_TOOLTIP,
+  META_WINDOW_NOTIFICATION,
+  META_WINDOW_COMBO,
+  META_WINDOW_DND,
+  META_WINDOW_OVERRIDE_OTHER
 } MetaWindowType;
 
 typedef enum
@@ -84,6 +93,8 @@ typedef enum {
 
 struct _MetaWindow
 {
+  GObject parent;
+
   MetaDisplay *display;
   MetaScreen *screen;
   MetaWorkspace *workspace;
@@ -96,7 +107,6 @@ struct _MetaWindow
   char *desc; /* used in debug spew */
   char *title;
 
-  char *icon_name;
   GdkPixbuf *icon;
   GdkPixbuf *mini_icon;
   MetaIconCache icon_cache;
@@ -129,6 +139,9 @@ struct _MetaWindow
   /* Initial timestamp property */
   guint32 initial_timestamp;
 
+  /* Whether this is an override redirect window or not */
+  guint override_redirect : 1;
+
   /* Whether we're maximized */
   guint maximized_horizontally : 1;
   guint maximized_vertically : 1;
@@ -153,9 +166,6 @@ struct _MetaWindow
   /* Whether we're fullscreen */
   guint fullscreen : 1;
 
-  /* Whether we have to fullscreen after placement */
-  guint fullscreen_after_placement : 1;
-
   /* Area to cover when in fullscreen mode.  If _NET_WM_FULLSCREEN_MONITORS has
    * been overridden (via a client message), the window will cover the union of
    * these monitors.  If not, this is the single monitor which the window's
@@ -179,7 +189,6 @@ struct _MetaWindow
 
   /* Minimize is the state controlled by the minimize button */
   guint minimized : 1;
-  guint was_minimized : 1;
   guint tab_unminimized : 1;
 
   /* Whether the window is mapped; actual server-side state
@@ -187,6 +196,17 @@ struct _MetaWindow
    */
   guint mapped : 1;
 
+  /* Whether the compositor thinks the window is visible.
+   * This should match up with calls to meta_compositor_show_window /
+   * meta_compositor_hide_window.
+   */
+  guint visible_to_compositor : 1;
+
+  /* When we next show or hide the window, what effect we should
+   * tell the compositor to perform.
+   */
+  guint pending_compositor_effect : 4;
+
   /* Iconic is the state in WM_STATE; happens for workspaces/shading
    * in addition to minimize
    */
@@ -205,6 +225,9 @@ struct _MetaWindow
   /* whether net_wm_user_time has been set yet */
   guint net_wm_user_time_set : 1;
 
+  /* whether net_wm_icon_geometry has been set */
+  guint icon_geometry_set : 1;
+
   /* These are the flags from WM_PROTOCOLS */
   guint take_focus : 1;
   guint delete_window : 1;
@@ -251,24 +274,19 @@ struct _MetaWindow
   /* EWHH demands attention flag */
   guint wm_state_demands_attention : 1;
 
-  /* this flag tracks receipt of focus_in focus_out and
-   * determines whether we draw the focus
-   */
+  /* TRUE if window == window->display->focus_window */
   guint has_focus : 1;
 
   /* Have we placed this window? */
   guint placed : 1;
 
-  /* Must we force_save_user_window_placement? */
-  guint force_save_user_rect : 1;
-
   /* Is this not a transient of the focus window which is being denied focus? */
   guint denied_focus_and_not_transient : 1;
 
   /* Has this window not ever been shown yet? */
   guint showing_for_first_time : 1;
 
-  /* Are we in meta_window_free()? */
+  /* Are we in meta_window_unmanage()? */
   guint unmanaging : 1;
 
   /* Are we in meta_window_new()? */
@@ -298,8 +316,6 @@ struct _MetaWindow
   /* Info on which props we got our attributes from */
   guint using_net_wm_name              : 1; /* vs. plain wm_name */
   guint using_net_wm_visible_name      : 1; /* tracked so we can clear it */
-  guint using_net_wm_icon_name         : 1; /* vs. plain wm_icon_name */
-  guint using_net_wm_visible_icon_name : 1; /* tracked so we can clear it */
 
   /* has a shape mask */
   guint has_shape : 1;
@@ -316,9 +332,24 @@ struct _MetaWindow
   /* if TRUE, application is buggy and SYNC resizing is turned off */
   guint disable_sync : 1;
 
+  /* if TRUE, window is attached to its parent */
+  guint attached : 1;
+
+  /* if TRUE, we are freezing updates during a resize */
+  guint updates_frozen_for_resize : 1;
+
   /* if non-NULL, the bounds of the window frame */
   cairo_region_t *frame_bounds;
 
+  /* if non-NULL, the bounding shape region of the window */
+  cairo_region_t *shape_region;
+
+  /* if non-NULL, the opaque region _NET_WM_OPAQUE_REGION */
+  cairo_region_t *opaque_region;
+
+  /* _NET_WM_WINDOW_OPACITY */
+  guint opacity;
+
   /* Note: can be NULL */
   GSList *struts;
 
@@ -326,6 +357,8 @@ struct _MetaWindow
   XSyncCounter sync_request_counter;
   guint sync_request_serial;
   GTimeVal sync_request_time;
+  /* alarm monitoring client's _NET_WM_SYNC_REQUEST_COUNTER */
+  XSyncAlarm sync_request_alarm;
 
   /* Number of UnmapNotify that are caused by us, if
    * we get UnmapNotify with none pending then the client
@@ -372,6 +405,9 @@ struct _MetaWindow
    */
   MetaRectangle user_rect;
 
+  /* Cached net_wm_icon_geometry */
+  MetaRectangle icon_geometry;
+
   /* Requested geometry */
   int border_width;
   /* x/y/w/h here get filled with ConfigureRequest values */
@@ -386,6 +422,9 @@ struct _MetaWindow
 
   /* maintained by group.c */
   MetaGroup *group;
+
+  /* Focused window that is (directly or indirectly) attached to this one */
+  MetaWindow *attached_focus_window;
 };
 
 /* These differ from window->has_foo_func in that they consider
@@ -411,14 +450,11 @@ struct _MetaWindow
 #define META_WINDOW_ALLOWS_HORIZONTAL_RESIZE(w) (META_WINDOW_ALLOWS_RESIZE_EXCEPT_HINTS (w) && (w)->size_hints.min_width < (w)->size_hints.max_width)
 #define META_WINDOW_ALLOWS_VERTICAL_RESIZE(w)   (META_WINDOW_ALLOWS_RESIZE_EXCEPT_HINTS (w) && (w)->size_hints.min_height < (w)->size_hints.max_height)
 
-MetaWindow* meta_window_new                (MetaDisplay *display,
-                                            Window       xwindow,
-                                            gboolean     must_be_viewable);
-MetaWindow* meta_window_new_with_attrs     (MetaDisplay *display,
-                                            Window       xwindow,
-                                            gboolean     must_be_viewable,
-                                            XWindowAttributes *attrs);
-void        meta_window_free               (MetaWindow  *window,
+MetaWindow* meta_window_new                (MetaDisplay    *display,
+                                            Window          xwindow,
+                                            gboolean        must_be_viewable,
+                                            MetaEffectType  effect);
+void        meta_window_unmanage           (MetaWindow  *window,
                                             guint32      timestamp);
 void        meta_window_calc_showing       (MetaWindow  *window);
 void        meta_window_queue              (MetaWindow  *window,
@@ -458,8 +494,6 @@ void        meta_window_update_fullscreen_monitors (MetaWindow    *window,
                                                     unsigned long  left,
                                                     unsigned long  right);
 
-gboolean    meta_window_appears_focused    (MetaWindow *window);
-
 /* args to move are window pos, not frame pos */
 void        meta_window_move               (MetaWindow  *window,
                                             gboolean     user_op,
@@ -557,8 +591,9 @@ gboolean meta_window_property_notify   (MetaWindow *window,
                                         XEvent     *event);
 gboolean meta_window_client_message    (MetaWindow *window,
                                         XEvent     *event);
-gboolean meta_window_notify_focus      (MetaWindow *window,
-                                        XEvent     *event);
+
+void     meta_window_set_focused_internal (MetaWindow *window,
+                                           gboolean    focused);
 
 void     meta_window_set_current_workspace_hint (MetaWindow *window);
 
@@ -571,12 +606,14 @@ void meta_window_show_menu (MetaWindow         *window,
 gboolean meta_window_titlebar_is_onscreen    (MetaWindow *window);
 void     meta_window_shove_titlebar_onscreen (MetaWindow *window);
 
-void meta_window_set_gravity (MetaWindow *window,
-                              int         gravity);
+void meta_window_update_sync_request_counter (MetaWindow *window,
+                                              guint64     new_counter_value);
 
 void meta_window_handle_mouse_grab_op_event (MetaWindow *window,
                                              XEvent     *event);
 
+MetaWorkspace *meta_window_get_workspace (MetaWindow *window);
+
 GList* meta_window_get_workspaces (MetaWindow *window);
 
 gboolean meta_window_located_on_workspace (MetaWindow    *window,
@@ -609,6 +646,9 @@ void meta_window_refresh_resize_popup (MetaWindow *window);
 
 void meta_window_free_delete_dialog (MetaWindow *window);
 
+void meta_window_create_sync_request_alarm  (MetaWindow *window);
+void meta_window_destroy_sync_request_alarm (MetaWindow *window);
+
 void     meta_window_foreach_transient        (MetaWindow            *window,
                                                MetaWindowForeachFunc  func,
                                                void                  *data);
@@ -634,6 +674,9 @@ void meta_window_update_layer (MetaWindow *window);
 gboolean meta_window_get_icon_geometry (MetaWindow    *window,
                                         MetaRectangle *rect);
 
+void     meta_window_set_icon_geometry (MetaWindow    *window,
+                                        MetaRectangle *rect);
+
 const char* meta_window_get_startup_id (MetaWindow *window);
 
 void meta_window_recalc_features    (MetaWindow *window);
@@ -661,4 +704,20 @@ gboolean meta_window_is_client_decorated (MetaWindow *window);
 void meta_window_get_titlebar_rect (MetaWindow    *window,
                                     MetaRectangle *titlebar_rect);
 
+void meta_window_configure_notify (MetaWindow      *window,
+                                   XConfigureEvent *event);
+
+void meta_window_propagate_focus_appearance (MetaWindow *window,
+                                             gboolean    focused);
+
+gboolean meta_window_should_attach_to_parent (MetaWindow *window);
+
+MetaFrameType meta_window_get_frame_type (MetaWindow *window);
+
+gboolean meta_window_updates_are_frozen (MetaWindow *window);
+
+void meta_window_update_shape_region (MetaWindow *window);
+
+G_END_DECLS
+
 #endif
