@@ -32,9 +32,6 @@
 #include <libmetacity/meta-frame-borders.h>
 #include <libmetacity/meta-frame-enums.h>
 
-/* This is between GTK_PRIORITY_RESIZE (+10) and GDK_PRIORITY_REDRAW (+20) */
-#define META_PRIORITY_RESIZE    (G_PRIORITY_HIGH_IDLE + 15)
-
 typedef struct _MetaUI MetaUI;
 
 typedef gboolean (* MetaEventFunc) (XEvent *xevent, gpointer data);
@@ -56,10 +53,15 @@ void meta_ui_remove_event_func (Display       *xdisplay,
                                 MetaEventFunc  func,
                                 gpointer       data);
 
-MetaUI* meta_ui_new (Display *xdisplay,
-                     Screen  *screen);
+MetaUI* meta_ui_new (Display  *xdisplay,
+                     gboolean  composited);
 void    meta_ui_free (MetaUI *ui);
 
+void meta_ui_set_composited (MetaUI   *ui,
+                             gboolean  composited);
+
+gint meta_ui_get_scale (MetaUI *ui);
+
 void meta_ui_theme_get_frame_borders (MetaUI           *ui,
                                       MetaFrameType     type,
                                       MetaFrameFlags    flags,
@@ -80,7 +82,8 @@ Window meta_ui_create_frame_window (MetaUI  *ui,
                                     gint     x,
                                     gint     y,
                                     gint     width,
-                                    gint     height);
+                                    gint     height,
+                                    gulong  *create_serial);
 
 void meta_ui_destroy_frame_window (MetaUI *ui,
 				   Window  xwindow);
@@ -154,8 +157,8 @@ GdkPixbuf* meta_ui_get_default_mini_icon (MetaUI *ui);
 gboolean  meta_ui_window_should_not_cause_focus (Display *xdisplay,
                                                  Window   xwindow);
 
-void meta_ui_reload_theme (void);
-void meta_ui_update_button_layout (void);
+void meta_ui_reload_theme (MetaUI *ui);
+void meta_ui_update_button_layout (MetaUI *ui);
 
 /* Not a real key symbol but means "key above the tab key"; this is
  * used as the default keybinding for cycle_group.
