@@ -20,13 +20,18 @@
 #ifndef META_WINDOW_H
 #define META_WINDOW_H
 
-#include <glib.h>
 #include <cairo.h>
+#include <glib-object.h>
 #include <X11/Xlib.h>
 
 #include "boxes.h"
 #include "types.h"
 
+G_BEGIN_DECLS
+
+#define META_TYPE_WINDOW meta_window_get_type ()
+G_DECLARE_FINAL_TYPE (MetaWindow, meta_window, META, WINDOW, GObject)
+
 MetaFrame *meta_window_get_frame (MetaWindow *window);
 gboolean meta_window_has_focus (MetaWindow *window);
 gboolean meta_window_is_shaded (MetaWindow *window);
@@ -36,7 +41,10 @@ Window meta_window_get_xwindow (MetaWindow *window);
 MetaWindow *meta_window_get_transient_for (MetaWindow *window);
 gboolean meta_window_is_fullscreen (MetaWindow *window);
 gboolean meta_window_is_maximized (MetaWindow *window);
-
+gboolean meta_window_is_attached_dialog (MetaWindow *window);
+gboolean meta_window_appears_focused (MetaWindow *window);
 cairo_region_t *meta_window_get_frame_bounds (MetaWindow *window);
 
+G_END_DECLS
+
 #endif
