@@ -87,6 +87,8 @@ struct _MetaFrames
 {
   GtkWindow    parent;
 
+  MetaUI      *ui;
+
   Display     *xdisplay;
 
   GHashTable  *frames;
@@ -103,6 +105,14 @@ struct _MetaFrames
 
 G_DEFINE_TYPE (MetaFrames, meta_frames, GTK_TYPE_WINDOW)
 
+static void
+process_all_updates (void)
+{
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+  gdk_window_process_all_updates ();
+  G_GNUC_END_IGNORE_DEPRECATIONS
+}
+
 static void
 get_client_rect (MetaFrameGeometry *fgeom,
                  GdkRectangle      *rect)
@@ -150,7 +160,7 @@ get_control (MetaFrames  *frames,
                  META_CORE_GET_FRAME_TYPE, &type,
                  META_CORE_GET_END);
 
-  theme = meta_ui_get_theme ();
+  theme = meta_ui_get_theme (frames->ui);
   button = meta_theme_get_button (theme, x, y);
 
   if (button != NULL)
@@ -284,7 +294,8 @@ get_control (MetaFrames  *frames,
 }
 
 static gboolean
-get_control_rect (MetaFrameControl   control,
+get_control_rect (MetaFrames        *frames,
+                  MetaFrameControl   control,
                   MetaFrameGeometry *fgeom,
                   gint               x,
                   gint               y,
@@ -363,7 +374,7 @@ get_control_rect (MetaFrameControl   control,
   if (type == META_BUTTON_TYPE_LAST)
     return FALSE;
 
-  theme = meta_ui_get_theme ();
+  theme = meta_ui_get_theme (frames->ui);
   button = meta_theme_get_button (theme, x, y);
 
   if (button == NULL || meta_button_get_type (button) != type)
@@ -420,9 +431,7 @@ static void
 prefs_changed_callback (MetaPreference pref,
                         void          *data)
 {
-  if (pref == META_PREF_COMPOSITING_MANAGER)
-    meta_frames_style_updated (GTK_WIDGET (data));
-  else if (pref == META_PREF_TITLEBAR_FONT)
+  if (pref == META_PREF_TITLEBAR_FONT)
     meta_frames_font_changed (META_FRAMES (data));
   else if (pref == META_PREF_BUTTON_LAYOUT)
     meta_frames_button_layout_changed (META_FRAMES (data));
@@ -598,7 +607,7 @@ meta_frames_font_changed (MetaFrames *frames)
   MetaTheme *theme;
   const PangoFontDescription *titlebar_font;
 
-  theme = meta_ui_get_theme ();
+  theme = meta_ui_get_theme (frames->ui);
   titlebar_font = meta_prefs_get_titlebar_font ();
 
   meta_theme_set_titlebar_font (theme, titlebar_font);
@@ -645,14 +654,10 @@ meta_frames_style_updated (GtkWidget *widget)
 {
   MetaFrames *frames;
   MetaTheme *theme;
-  gboolean compositing_manager;
 
   frames = META_FRAMES (widget);
+  theme = meta_ui_get_theme (frames->ui);
 
-  theme = meta_ui_get_theme ();
-  compositing_manager = meta_prefs_get_compositing_manager ();
-
-  meta_theme_set_composited (theme, compositing_manager);
   meta_theme_invalidate (theme);
 
   meta_frames_font_changed (frames);
@@ -681,18 +686,18 @@ meta_frames_calc_geometry (MetaFrames        *frames,
                  META_CORE_GET_FRAME_TYPE, &type,
                  META_CORE_GET_END);
 
-  meta_theme_calc_geometry (meta_ui_get_theme (), frame->theme_variant,
-                            type, flags, width, height, fgeom);
+  meta_theme_calc_geometry (meta_ui_get_theme (frames->ui),
+                            frame->theme_variant, type, flags,
+                            width, height, fgeom);
 }
 
 MetaFrames*
-meta_frames_new (void)
+meta_frames_new (MetaUI *ui)
 {
   MetaFrames *frames;
 
-  frames = g_object_new (META_TYPE_FRAMES,
-                         "type", GTK_WINDOW_POPUP,
-                         NULL);
+  frames = g_object_new (META_TYPE_FRAMES, "type", GTK_WINDOW_POPUP, NULL);
+  frames->ui = ui;
 
   /* Put the window at an arbitrary offscreen location; the one place
    * it can't be is at -100x-100, since the meta_window_new() will
@@ -822,7 +827,9 @@ meta_frames_unmanage_window (MetaFrames *frames,
       g_free (frame);
     }
   else
-    meta_warning ("Frame 0x%lx not managed, can't unmanage\n", xwindow);
+    {
+      g_warning ("Frame 0x%lx not managed, can't unmanage", xwindow);
+    }
 }
 
 static MetaUIFrame*
@@ -856,8 +863,9 @@ meta_ui_frame_get_borders (MetaFrames       *frames,
    * by the core move/resize code to decide on the client
    * window size
    */
-  meta_theme_get_frame_borders (meta_ui_get_theme (), frame->theme_variant,
-                                type, flags, borders);
+  meta_theme_get_frame_borders (meta_ui_get_theme (frames->ui),
+                                frame->theme_variant, type,
+                                flags, borders);
 }
 
 void
@@ -870,7 +878,7 @@ meta_frames_get_borders (MetaFrames       *frames,
   frame = meta_frames_lookup_window (frames, xwindow);
 
   if (frame == NULL)
-    meta_bug ("No such frame 0x%lx\n", xwindow);
+    g_error ("No such frame 0x%lx", xwindow);
 
   meta_ui_frame_get_borders (frames, frame, borders);
 }
@@ -940,7 +948,7 @@ get_visible_region (MetaFrames        *frames,
   if (fgeom->top_left_corner_rounded_radius != 0)
     {
       const int corner = fgeom->top_left_corner_rounded_radius;
-      const float radius = sqrt(corner) + corner;
+      const gdouble radius = sqrt (corner) + corner;
       int i;
 
       for (i=0; i<corner; i++)
@@ -958,7 +966,7 @@ get_visible_region (MetaFrames        *frames,
   if (fgeom->top_right_corner_rounded_radius != 0)
     {
       const int corner = fgeom->top_right_corner_rounded_radius;
-      const float radius = sqrt(corner) + corner;
+      const gdouble radius = sqrt (corner) + corner;
       int i;
 
       for (i=0; i<corner; i++)
@@ -976,7 +984,7 @@ get_visible_region (MetaFrames        *frames,
   if (fgeom->bottom_left_corner_rounded_radius != 0)
     {
       const int corner = fgeom->bottom_left_corner_rounded_radius;
-      const float radius = sqrt(corner) + corner;
+      const gdouble radius = sqrt (corner) + corner;
       int i;
 
       for (i=0; i<corner; i++)
@@ -994,7 +1002,7 @@ get_visible_region (MetaFrames        *frames,
   if (fgeom->bottom_right_corner_rounded_radius != 0)
     {
       const int corner = fgeom->bottom_right_corner_rounded_radius;
-      const float radius = sqrt(corner) + corner;
+      const gdouble radius = sqrt (corner) + corner;
       int i;
 
       for (i=0; i<corner; i++)
@@ -1056,7 +1064,6 @@ meta_frames_apply_shapes (MetaFrames *frames,
   MetaUIFrame *frame;
   MetaFrameGeometry fgeom;
   cairo_region_t *window_region;
-  gboolean compositing_manager;
 
   frame = meta_frames_lookup_window (frames, xwindow);
   g_return_if_fail (frame != NULL);
@@ -1074,9 +1081,7 @@ meta_frames_apply_shapes (MetaFrames *frames,
 
   meta_frames_calc_geometry (frames, frame, &fgeom);
 
-  compositing_manager = meta_prefs_get_compositing_manager ();
-
-  if (!window_has_shape && compositing_manager)
+  if (!window_has_shape && meta_ui_is_composited (frames->ui))
     return;
 
   window_region = get_visible_region (frames,
@@ -1144,7 +1149,7 @@ meta_frames_apply_shapes (MetaFrames *frames,
                                          new_window_width,
                                          new_window_height);
 
-      tmp_region = compositing_manager ? frame_region : window_region;
+      tmp_region = meta_ui_is_composited (frames->ui) ? frame_region : window_region;
 
       cairo_region_subtract (tmp_region, client_region);
 
@@ -1172,7 +1177,7 @@ meta_frames_apply_shapes (MetaFrames *frames,
                   "Frame 0x%lx has shaped corners\n",
                   frame->xwindow);
 
-      if (!compositing_manager)
+      if (!meta_ui_is_composited (frames->ui))
         apply_cairo_region_to_window (frames->xdisplay,
                                       frame->xwindow, window_region,
                                       ShapeSet);
@@ -1279,9 +1284,7 @@ meta_frames_repaint_frame (MetaFrames *frames,
   /* repaint everything, so the other frame don't
    * lag behind if they are exposed
    */
-  G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-  gdk_window_process_all_updates ();
-  G_GNUC_END_IGNORE_DEPRECATIONS
+  process_all_updates ();
 }
 
 static void
@@ -1376,7 +1379,7 @@ show_tip_now (MetaFrames *frames)
 
       meta_frames_calc_geometry (frames, frame, &fgeom);
 
-      if (!get_control_rect (control, &fgeom, x, y, &rect))
+      if (!get_control_rect (frames, control, &fgeom, x, y, &rect))
         return;
 
       /* get conversion delta for root-to-frame coords */
@@ -1441,7 +1444,7 @@ redraw_control (MetaFrames       *frames,
 
   meta_frames_calc_geometry (frames, frame, &fgeom);
 
-  if (!get_control_rect (control, &fgeom, x, y, &rect))
+  if (!get_control_rect (frames, control, &fgeom, x, y, &rect))
     return;
 
   gdk_window_invalidate_rect (frame->window, &rect, FALSE);
@@ -1825,7 +1828,7 @@ meta_frames_button_press_event (GtkWidget      *widget,
 
           meta_frames_calc_geometry (frames, frame, &fgeom);
 
-          if (!get_control_rect (META_FRAME_CONTROL_MENU, &fgeom,
+          if (!get_control_rect (frames, META_FRAME_CONTROL_MENU, &fgeom,
                                  event->x, event->y, &rect))
             {
               return FALSE;
@@ -2259,7 +2262,7 @@ generate_pixmap (MetaFrames            *frames,
 }
 
 static void
-populate_cache (MetaFrames *frames,
+populate_cache (MetaFrames  *frames,
                 MetaUIFrame *frame)
 {
   MetaFrameBorders borders;
@@ -2288,8 +2291,9 @@ populate_cache (MetaFrames *frames,
       return;
     }
 
-  meta_theme_get_frame_borders (meta_ui_get_theme (), frame->theme_variant,
-                                frame_type, frame_flags, &borders);
+  meta_theme_get_frame_borders (meta_ui_get_theme (frames->ui),
+                                frame->theme_variant, frame_type,
+                                frame_flags, &borders);
 
   pixels = get_cache (frames, frame);
 
@@ -2348,8 +2352,8 @@ populate_cache (MetaFrames *frames,
 }
 
 static void
-subtract_client_area (cairo_region_t *region,
-                      Display        *xdisplay,
+subtract_client_area (MetaFrames     *frames,
+                      cairo_region_t *region,
                       MetaUIFrame    *frame)
 {
   cairo_rectangle_int_t area;
@@ -2358,15 +2362,16 @@ subtract_client_area (cairo_region_t *region,
   MetaFrameBorders borders;
   cairo_region_t *tmp_region;
 
-  meta_core_get (xdisplay, frame->xwindow,
+  meta_core_get (frames->xdisplay, frame->xwindow,
                  META_CORE_GET_FRAME_FLAGS, &flags,
                  META_CORE_GET_FRAME_TYPE, &type,
                  META_CORE_GET_CLIENT_WIDTH, &area.width,
                  META_CORE_GET_CLIENT_HEIGHT, &area.height,
                  META_CORE_GET_END);
 
-  meta_theme_get_frame_borders (meta_ui_get_theme (), frame->theme_variant,
-                                type, flags, &borders);
+  meta_theme_get_frame_borders (meta_ui_get_theme (frames->ui),
+                                frame->theme_variant, type,
+                                flags, &borders);
 
   area.x = borders.total.left;
   area.y = borders.total.top;
@@ -2473,7 +2478,7 @@ meta_frames_draw (GtkWidget *widget,
 
   cached_pixels_draw (pixels, cr, region);
 
-  subtract_client_area (region, frames->xdisplay, frame);
+  subtract_client_area (frames, region, frame);
 
   n_areas = cairo_region_num_rectangles (region);
 
@@ -2670,7 +2675,7 @@ meta_frames_paint (MetaFrames  *frames,
   data.frames = frames;
   data.frame = frame;
 
-  meta_theme_draw_frame (meta_ui_get_theme (), frame->theme_variant,
+  meta_theme_draw_frame (meta_ui_get_theme (frames->ui), frame->theme_variant,
                          cr, type, flags, w, h, frame->title,
                          update_button_state, &data, mini_icon, icon);
 }
@@ -2732,9 +2737,7 @@ meta_frames_push_delay_exposes (MetaFrames *frames)
   if (frames->expose_delay_count == 0)
     {
       /* Make sure we've repainted things */
-      G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-      gdk_window_process_all_updates ();
-      G_GNUC_END_IGNORE_DEPRECATIONS
+      process_all_updates ();
       XFlush (frames->xdisplay);
     }
 
@@ -2779,3 +2782,9 @@ invalidate_whole_window (MetaFrames *frames,
   gdk_window_invalidate_rect (frame->window, NULL, FALSE);
   invalidate_cache (frames, frame);
 }
+
+void
+meta_frames_composited_changed (MetaFrames *frames)
+{
+  g_hash_table_foreach (frames->frames, queue_recalc_func, frames);
+}
