@@ -872,8 +872,9 @@ meta_ui_reload_theme (MetaUI *ui)
       theme = load_theme (ui, META_THEME_TYPE_GTK, "Adwaita");
     }
 
-  g_set_object (&ui->theme, theme);
-  g_assert (ui->theme);
+  g_assert (theme);
+  g_clear_object (&ui->theme);
+  ui->theme = theme;
 
   meta_invalidate_default_icons ();
 }
@@ -956,7 +957,7 @@ meta_ui_parse_accelerator (const char          *accel,
   *keycode = 0;
   *mask = 0;
 
-  if (strcmp (accel, "disabled") == 0)
+  if (!accel[0] || strcmp (accel, "disabled") == 0)
     return TRUE;
 
   meta_ui_accelerator_parse (accel, &gdk_sym, &gdk_code, &gdk_mask);
@@ -1006,7 +1007,7 @@ meta_ui_parse_modifier (const char          *accel,
 
   *mask = 0;
 
-  if (accel == NULL || strcmp (accel, "disabled") == 0)
+  if (accel == NULL || !accel[0] || strcmp (accel, "disabled") == 0)
     return TRUE;
 
   meta_ui_accelerator_parse (accel, &gdk_sym, &gdk_code, &gdk_mask);
